xsdata.formats.dataclass.parsers.config module
==============================================

.. automodule:: xsdata.formats.dataclass.parsers.config
   :members:
   :undoc-members:
   :show-inheritance:
